#
# spec file for package python-langtable
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "data"
%define psuffix -data-src
%bcond_without data
%else
%define psuffix %{nil}
%bcond_with data
%endif
%define skip_python2 1
%global literalpython python
Name:           python-langtable%{psuffix}
Version:        0.0.68
Release:        1.2
Summary:        Database to guess defaults for locale settings
# the translations in languages.xml and territories.xml are (mostly)
# imported from CLDR and are thus under the Unicode license, the
# short name for this license is "MIT", see:
# https://fedoraproject.org/wiki/Licensing:MIT?rd=Licensing/MIT#Modern_Style_without_sublicense_.28Unicode.29
License:        GPL-3.0-or-later
Group:          System/Localization
URL:            https://github.com/mike-fabian/langtable
Source0:        https://github.com/mike-fabian/langtable/releases/download/%{version}/langtable-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  libxml2-tools
BuildRequires:  python-rpm-macros
%if %{without data}
Requires:       %{literalpython}-langtable-data = %{version}
%endif
BuildArch:      noarch
%python_subpackages

%description
langtable is used to guess reasonable defaults for locale, keyboard layout,
territory, and language, if part of that information is already known. For
example, guess the territory and the keyboard layout if the language
is known or guess the language and keyboard layout if the territory is
already known.

%package -n python-langtable-data
Summary:        XML data to map various locale settingsn and its relations

%description -n python-langtable-data
Provides XML data used by python-langtable. Packaged separately so it is not affected
by more python target versions and also it can be used indenpendently.

%prep
%autosetup -n langtable-%{version}

%build
%python_build

%install

%if %{with data}
# Data package
  mkdir -p %{buildroot}/%{_datadir}/langtable/data
  mv langtable/data/* %{buildroot}/%{_datadir}/langtable/data
%else
# Main package
  %python_install
  %python_expand %fdupes %{buildroot}%{$python_sitelib}
  %python_expand rm -rf %{buildroot}%{$python_sitelib}/langtable/data
%endif

# Main package
%if %{without data}

%check
(cd langtable; python3 langtable.py)
python3 test_cases.py
for i in keyboards languages territories timezoneidparts timezones; do
    xmllint --noout --relaxng \
	langtable/schemas/$i.rng \
	langtable/data/$i.xml.gz
done

%files %{python_files}
%license COPYING unicode-license.txt
%doc README ChangeLog
%{python_sitelib}/*

%else
# Data package

%files -n python-langtable-data
%{_datadir}/langtable
%endif

%changelog
* Sun Sep 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.68:
  * Reorder ibus/chewing as the default inputmethod for TW or
    Hant.
  * Add ltg_LV.UTF-8
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.67:
  * Add tool to check which languages, scripts, and territories
    available in CLDR are missing in langtable
  * Add all missing scripts and languages: yrl, xnr, wbp, vmw,
    vec, trw, trv, skr, sdh, quc, pis, pcm, myv, mus, moh, mic,
    mhn, ltg, lmo, lld, kxv, kpe, kgp, ken, kcg, kaj, jbo, gaa,
    cic, cho, ceb, cch, cad, bss, blt, Tavt blo, bgn, bgc, rhg,
    Rohg hnj, Hmnp Shaw, Dsrt bew, bal, arn, apc, ann, scn
  * Drop Python < 3 support (using pyupgrade --py3-plus
    langtable.py)
  * Fix some ruff and pylint warnings
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.66:
  * Fix syntax error in a keyboard layout name for t
  * Add mdf
  * Use “in(eng)” keyboard layout instead of “us” for BD to get
    AltGr enabled
  * Get translation changes from CLDR
  * Add option to include changed translations as well to the
    script getting translations from CLDR
  * Fix Makefile twine-upload target for new authentification
* Thu Feb  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.65:
  * Add wuu, tok, glk, gbm, ssy
  * Remove aa_ER.UTF-8@saaho
  * Add kv_RU.UTF-8, chr_RU.UTF-8
  * Add EU, EZ
  * Add more translations from CLDR
  * Get translation changes from CLDR
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.0.64:
  * Add new public functions list_all_{languages,locales,keyboard
    s,territories,timezones,scripts,input_methods,console_fonts}
- update to 0.0.63:
  * Japanese: prefer anthy over kkc
  * Use skipTerritory also in list_keyboards(),
    list_consolefonts(), and list_timezones()
  * Add more translations from CLDR
  * Get translation changes from CLDR
- update to 0.0.62:
  * Get translation changes from CLDR
  * Add more translations from CLDR
  * Add Norwegian keyboard layout to keyboards.xml (Resolves:
    https://github.com/mike-fabian/langtable/issues/16)
  * Add Hang script to Southern Aymara
* Thu May 25 2023 Daniel Garcia <daniel.garcia@suse.com>
- Build data package with multibuild
* Thu Apr 27 2023 Josef Reidinger <jreidinger@suse.com>
- Split python-langtable-data subpackage to hold XML data that
  package use it saves some spaces and allows usage of that XML
  without python dependency
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.0.61
  * Add mnw_MM.UTF-8 and ckb_IQ.UTF-8
  * Do not run test cases using Python2 anymore
  * Add bih
  * Add more translations from CLDR
  * Migrate license tag to SPDX
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.0.60
  * Add list_common_locales() function (Resolves: #15)
  * For ar_IN locale, langtable should give the 'ara' keyboard layout as the first choice (Resolves: Resolves: #14)
* Tue Sep  6 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 0.0.58 -> 0.0.59
- Add ibus/m17n:ar:kbd as input method for Arabic and fix iso639-1 code for Arabic
- Add new translations and changes to translations from CLDR
* Sun Jun 26 2022 Gordon Leung <pirateclip@protonmail.com> - 0.0.58
  update: 0.0.51 -> 0.0.58
- add list_common_keyboards() to public api (Sundeep Anand suanand@redhat.com)
- Capitalize the return values of language_name() and territory_name()
  * gh#rhinstaller/anaconda#2837
- Add more translations and changes from CLDR
- add list_common_languages derived from gnome-control-center (Sundeep Anand suanand@redhat.com)
- Make inscript2 instead of inscript input methods the default
  * https://fedoraproject.org/wiki/Changes/Enhanced_Inscript_as_default_Indic_IM
- Make ibus/m17n:vi:telex the default input method for Vietnamese
- Fallback to translations in “xx” from “xx_Zzzz” only if “Zzzz” is the main script of “xx”
  * gh#mike-fabian/langtable#13
- Replace “ibus/cangjie” with “ibus/table:cangjie5”
- Update Sami languages and Finnish keyboard layouts (from Marko Myllynen)
- Add syr and ab_GE locales
- Add rif language
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros dependency
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.0.51
  * Parse stuff in glibc locale names after @ which is not a script as a variant
  * Add ckb_IQ.UTF-8 locale
  * Make parse_locale() return something reasonable for
    C, POSIX, en_US_POSIX, and C.UTF-8
  * Fix exception in language_name() when called with languageId=''
  * Add new public function parse_locale()
  * Let info() print a bit more stuff
* Thu Nov  7 2019 Ludwig Nussel <lnussel@suse.de>
- initial package version 0.0.48 for openSUSE
